"""TypeVar test."""

class UserDict:
    def __init__(self, initialdata = None):
        pass
